================
FUNT
================

A Python library for university votes

=======

The purpose of the application is to simulate a university booklet, it presents the user with a list that will display the history of exams taken, indicating the name of the course and the grade obtained and the date of entry.
In addition, there is a form in which to enter a new record in the exam history, specifying the course and the grade obtained, the date of exam entry will be acquired automatically.
This data will be entered within a database, and it will then be possible for the user, via appropriate button, calculate the average of the grades obtained.
